<?php

declare(strict_types=1);

namespace Dedi\SyliusCustomerPoolPlugin\DataFixtures\Factory;

use Dedi\SyliusCustomerPoolPlugin\Model\CustomerPoolInterface;
use Sylius\Bundle\CoreBundle\Fixture\Factory\AbstractExampleFactory;
use Sylius\Bundle\CoreBundle\Fixture\Factory\ExampleFactoryInterface;
use Sylius\Component\Core\Formatter\StringInflector;
use Sylius\Component\Resource\Factory\FactoryInterface;
use Symfony\Component\OptionsResolver\Options;
use Symfony\Component\OptionsResolver\OptionsResolver;

class CustomerPoolExampleFactory extends AbstractExampleFactory implements ExampleFactoryInterface
{
    /** @var FactoryInterface */
    private $factory;

    /** @var \Faker\Generator */
    private $faker;

    /** @var OptionsResolver */
    private $optionsResolver;

    public function __construct(
        FactoryInterface $factory
    ) {
        $this->factory = $factory;

        $this->faker = \Faker\Factory::create();
        $this->optionsResolver = new OptionsResolver();

        $this->configureOptions($this->optionsResolver);
    }

    public function create(array $options = []): CustomerPoolInterface
    {
        $options = $this->optionsResolver->resolve($options);

        /** @var CustomerPoolInterface $customerPool */
        $customerPool = $this->factory->createNew();
        $customerPool->setCode($options['code']);
        $customerPool->setName($options['name']);

        return $customerPool;
    }

    protected function configureOptions(OptionsResolver $resolver): void
    {
        $resolver
            ->setDefault('code', function (Options $options): string {
                return StringInflector::nameToCode($options['name']);
            })
            ->setDefault('name', function (Options $options): string {
                /** @var string $words */
                $words = $this->faker->words(3, true);

                return $words;
            })
        ;
    }
}
