<?php

declare(strict_types=1);

namespace Dedi\SyliusCustomerPoolPlugin\DataFixtures\Factory;

use Dedi\SyliusCustomerPoolPlugin\Model\Customer\CustomerPoolAwareInterface;
use Sylius\Bundle\CoreBundle\Fixture\Factory\ShopUserExampleFactory;
use Sylius\Component\Core\Model\CustomerInterface;
use Sylius\Component\Core\Model\ShopUserInterface;
use Sylius\Component\Resource\Factory\FactoryInterface;
use Sylius\Component\Resource\Repository\RepositoryInterface;
use Webmozart\Assert\Assert;

class ShopUserWithCustomerPoolFactory extends ShopUserExampleFactory
{
    /** @var RepositoryInterface */
    private $customerPoolRepository;

    public function __construct(
        FactoryInterface $shopUserFactory,
        FactoryInterface $customerFactory,
        RepositoryInterface $customerGroupRepository,
        RepositoryInterface $customerPoolRepository
    ) {
        parent::__construct(
            $shopUserFactory,
            $customerFactory,
            $customerGroupRepository
        );

        $this->customerPoolRepository = $customerPoolRepository;
    }

    public function create(array $options = []): ShopUserInterface
    {
        $user = parent::create($options);

        /** @var CustomerInterface|CustomerPoolAwareInterface $customer */
        $customer = $user->getCustomer();
        Assert::isInstanceOf($customer, CustomerPoolAwareInterface::class);

        $customerPool = $this->customerPoolRepository->findOneBy(['code' => 'Default']);
        $customer->setCustomerPool($customerPool);

        return $user;
    }
}
